sphinx-quickstart manual page — flask-peewee v0.1.0 documentation

### Navigation

- index
- modules |
- flask-peewee v0.1.0 documentation »

# sphinx-quickstart manual page

## Synopsis

sphinx-quickstart

## Description

sphinx-quickstart is an interactive tool that asks some questions about your project and then generates a complete documentation directory and sample Makefile to be used with sphinx-build(1).

## See also

sphinx-build(1)

## Author

Georg Brandl <georg@python.org>, Armin Ronacher <armin.ronacher@active-4.com> et al.

This manual page was initially written by Mikhail Gusarov <dottedmag@dottedmag.net>, for the Debian project.

### Navigation

- index
- modules |
- flask-peewee v0.1.0 documentation »